package VM::JiffyBox;
{
  $VM::JiffyBox::VERSION = '0.0021';
}

# The line below is recognised by Dist::Zilla and taken for CPAN packaging
# ABSTRACT: OO-API for JiffyBox Virtual Machine

use Moo;

1;

__END__

=pod

=head1 NAME

VM::JiffyBox - OO-API for JiffyBox Virtual Machine

=head1 VERSION

version 0.0021

=encoding utf8

=head1 ON THIS MODULE

This module ist still under heavy development.
Releases including code can only be found as B<TRIAL>-uploads which are not indexed on CPAN.

B<THIS MODULE IS A PLACEHOLDER AND CONTAINS ONLY THIS TEXT AND NO CODE>.

If you wish to watch the development, please point your browser to here:

=over

=item * L<https://github.com/tim-schwarz/VM-JiffyBox>

=back

Modul will be out somwhere in summer 2013.

=head1 AUTHOR

Tim Schwarz, Boris Däppen <boris_daeppen@bluewin.ch>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Tim Schwarz, Boris Däppen, plusW.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
